@@ -1,31 +1,38 @@
 # coding=utf-8
-"""Bugzilla issue reporting module
-
+"""
+bugzilla.py - Sopel Bugzilla Module
 Copyright 2013-2015, Embolalia, embolalia.com
 Licensed under the Eiffel Forum License 2.
+
+https://sopel.chat
 """
 from __future__ import unicode_literals, absolute_import, print_function, division
 
+import logging
 import re
 
+import requests
 import xmltodict
 
-from sopel import web, tools
 from sopel.config.types import StaticSection, ListAttribute
-from sopel.logger import get_logger
 from sopel.module import rule
 
 
 regex = None
-LOGGER = get_logger(__name__)
+LOGGER = logging.getLogger(__name__)
 
 
 class BugzillaSection(StaticSection):
     domains = ListAttribute('domains')
-    """The domains of the Bugzilla instances from which to get information."""
+    """A list of Bugzilla issue tracker domains from which to get information."""
 
 
 def configure(config):
+    """
+    | name | example | purpose |
+    | ---- | ------- | ------- |
+    | domains | bugzilla.redhat.com,bugzilla.mozilla.org | A list of Bugzilla issue tracker domains |
+    """
     config.define_section('bugzilla', BugzillaSection)
     config.bugzilla.configure_setting(
         'domains',
@@ -40,24 +47,22 @@ def setup(bot):
 
     if not bot.config.bugzilla.domains:
         return
-    if not bot.memory.contains('url_callbacks'):
-        bot.memory['url_callbacks'] = tools.SopelMemory()
 
     domains = '|'.join(bot.config.bugzilla.domains)
     regex = re.compile((r'https?://(%s)'
-                        '(/show_bug.cgi\?\S*?)'
-                        '(id=\d+)')
+                        r'(/show_bug.cgi\?\S*?)'
+                        r'(id=\d+)')
                        % domains)
-    bot.memory['url_callbacks'][regex] = show_bug
+    bot.register_url_callback(regex, show_bug)
 
 
 def shutdown(bot):
-    del bot.memory['url_callbacks'][regex]
+    bot.unregister_url_callback(regex, show_bug)
 
 
 @rule(r'.*https?://(\S+?)'
-      '(/show_bug.cgi\?\S*?)'
-      '(id=\d+).*')
+      r'(/show_bug.cgi\?\S*?)'
+      r'(id=\d+).*')
 def show_bug(bot, trigger, match=None):
     """Show information about a Bugzilla bug."""
     match = match or trigger
@@ -65,12 +70,14 @@ def show_bug(bot, trigger, match=None):
     if domain not in bot.config.bugzilla.domains:
         return
     url = 'https://%s%sctype=xml&%s' % match.groups()
-    data = web.get(url, dont_decode=True)
+    data = requests.get(url).content
     bug = xmltodict.parse(data).get('bugzilla').get('bug')
     error = bug.get('@error', None)  # error="NotPermitted"
 
     if error:
-        LOGGER.warning('Bugzilla error: %s', error)
+        LOGGER.warning('Bugzilla error: %s' % error)
+        bot.say('[BUGZILLA] Unable to get information for '
+                'linked bug (%s)' % error)
         return
 
     message = ('[BUGZILLA] %s | Product: %s | Component: %s | Version: %s | ' +
